@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.1.8'
+version = '1.1.9'
 
 ###############################################################################
 # Some Imports
@@ -743,7 +743,7 @@ class Perturbations(object):
         try:
             return self.__power_cdm_0
         except:
-            self.__power_cdm_0 = tools.normalize(self.cosmo_params['sigma_8'], self._unnormalized_power,
+            self.__power_cdm_0, self._normalization = tools.normalize(self.cosmo_params['sigma_8'], self._unnormalized_power,
                                                                 self.lnk, self.cosmo_params['mean_dens'])
             return self.__power_cdm_0
 
@@ -1045,7 +1045,7 @@ class Perturbations(object):
     def _lower_ngtm(self, M, mass_function, cut):
         ### WE CALCULATE THE MASS FUNCTION BELOW THE COMPUTED RANGE ###
         # mass_function is logged already (not log10 though)
-        m_lower = np.linspace(np.log(10 ** 3), M[0], 500)
+        m_lower = np.linspace(np.log(10 ** 3), np.log(M[0]), 500)
         if cut:  #since its been cut, the best we can do is a power law
             mf_func = spline(np.log(M), mass_function, k=1)
             mf = mf_func(m_lower)
@@ -1163,15 +1163,16 @@ class Perturbations(object):
             M = self.M[np.logical_not(np.isnan(self.dndlnm))]
             mass_function = self.dndlnm[np.logical_not(np.isnan(self.dndlnm))]
 
-            #Calculate the mass function (and its integral) from the highest M up to 10**18
-            if M[-1] < 10 ** 18:
+            #Calculate the mass function (and its integral) from 10**3 up to lowest M
+            if M[0] > 10 ** 3:
                 m_lower, mf = self._lower_ngtm(M, np.log(mass_function), M[0] > self.M[0])
 
                 int_lower = intg.simps(np.exp(mf), dx=m_lower[2] - m_lower[1], even='first')
             else:
                 int_lower = 0
 
-            #Calculate the cumulative integral (backwards) of mass_function (Adding on the upper integral)
+            print "INT LOWER = ", int_lower
+            #Calculate the cumulative integral of mass_function (Adding on the lower integral)
             self.__nltm = intg.cumtrapz(mass_function, dx=np.log(M[1]) - np.log(M[0]), initial=0) + int_lower
 
             #We need to set ngtm back in the original length vector with nans where they were originally
@@ -1181,7 +1182,6 @@ class Perturbations(object):
                 nltm_temp[np.logical_not(np.isnan(self.dndlnm))] = self.__nltm
                 self.__nltm = nltm_temp
 
-
             return self.__nltm
     @nltm.deleter
     def nltm(self):
@@ -1202,15 +1202,15 @@ class Perturbations(object):
             M = self.M[np.logical_not(np.isnan(self.dndlnm))]
             mass_function = self.dndlnm[np.logical_not(np.isnan(self.dndlnm))]
 
-            #Calculate the mass function (and its integral) from the highest M up to 10**18
-            if M[-1] < 10 ** 18:
+            #Calculate the mass function (and its integral) from 10**3 up to lowest M
+            if M[0] > 10 ** 3:
                 m_lower, mf = self._lower_ngtm(M, np.log(mass_function), M[0] > self.M[0])
 
                 int_lower = intg.simps(np.exp(mf + m_lower), dx=m_lower[2] - m_lower[1], even='first')
             else:
                 int_lower = 0
 
-            #Calculate the cumulative integral (backwards) of mass_function (Adding on the upper integral)
+            #Calculate the cumulative integral of mass_function (Adding on the upper integral)
             self.__mltm = intg.cumtrapz(mass_function * M, dx=np.log(M[1]) - np.log(M[0]), initial=0) + int_lower
 
             #We need to set ngtm back in the original length vector with nans where they were originally
