@@ -159,7 +159,7 @@ def normalize(norm_sigma_8, unn_power, lnk, mean_dens):
 
     # Normalize the previously calculated power spectrum.
     power = 2 * np.log(normalization) + unn_power
-    return power
+    return power, normalization
 
 def mass_variance(M, power, lnk, mean_dens):
     """
